Examples
========

Fitting a function
------------------

.. literalinclude:: ../examples/CrabNebula_ecpl.py
    :language: python

Fitting IC emission from an electron distribution
-------------------------------------------------

.. literalinclude:: ../examples/CrabNebula_IC.py
    :language: python

Fitting pp emission from a proton distribution
----------------------------------------------

.. literalinclude:: ../examples/CrabNebula_proton.py
    :language: python
